@@ -1,14 +1,16 @@
 import sys
 import traceback
-from datetime import datetime, timedelta
-from os import environ
+from datetime import datetime
 
+import chalice
 from chalice import Chalice, ChaliceViewError, Response
+from chalice.app import EventSourceHandler as ChaliceEventSourceHandler
+from sentry_sdk._compat import reraise
 from sentry_sdk._types import MYPY
 from sentry_sdk.hub import Hub, _should_send_default_pii
 from sentry_sdk.integrations import Integration
 from sentry_sdk.integrations._wsgi_common import _filter_headers
-from sentry_sdk.integrations.aws_lambda import AwsLambdaIntegration
+from sentry_sdk.integrations.aws_lambda import _get_cloudwatch_logs_url
 from sentry_sdk.utils import (
     AnnotatedValue,
     capture_internal_exceptions,
@@ -21,6 +23,30 @@ if MYPY:
     from sentry_sdk._types import Event, EventProcessor, Hint
 
 
+class EventSourceHandler(ChaliceEventSourceHandler):
+    def __call__(self, event, context):
+        hub = Hub.current
+        client = hub.client
+
+        with hub.push_scope() as scope:
+            try:
+                event_obj = self.event_class(event, context)
+                return self.func(event_obj)
+            except Exception:
+                scope.add_event_processor(
+                    _make_request_event_processor(event, context)
+                )
+                exc_info = sys.exc_info()
+                event, hint = event_from_exception(
+                    exc_info,
+                    client_options=client.options,
+                    mechanism={"type": "chalice", "handled": False},
+                )
+                hub.capture_event(event, hint=hint)
+                hub.flush()
+                reraise(*exc_info)
+
+
 def _get_view_function_response(app, view_function, function_args):
     hub = Hub.current
     client = hub.client
@@ -83,7 +109,7 @@ class ChaliceIntegration(Integration):
         # for @app.route()
         Chalice._get_view_function_response = _get_view_function_response
         # for everything else (like events)
-        AwsLambdaIntegration.setup_once()
+        chalice.app.EventSourceHandler = EventSourceHandler
 
 
 def _make_request_event_processor(current_request, lambda_context):
@@ -92,36 +118,32 @@ def _make_request_event_processor(current_request, lambda_context):
 
     def event_processor(event, hint, start_time=start_time):
         # type: (Event, Hint, datetime) -> Optional[Event]
+
         extra = event.setdefault("extra", {})
-        extra["lambda"] = {
+
+        extra["Chalice-lambda"] = {
             "function_name": lambda_context.function_name,
             "function_version": lambda_context.function_version,
-            "invoked_function_arn": lambda_context.invoked_function_arn,
+            "Lambda ARN": lambda_context.invoked_function_arn,
             "aws_request_id": lambda_context.aws_request_id,
         }
 
-        extra["cloudwatch logs"] = {
+        extra["cloudwatch info"] = {
             "url": _get_cloudwatch_logs_url(lambda_context, start_time),
             "log_group": lambda_context.log_group_name,
             "log_stream": lambda_context.log_stream_name,
         }
 
-        request = event.get("request", {})
-        if "httpMethod" in current_request.context:
-            request["method"] = current_request.context["httpMethod"]
+        request_info = event.get("request", {})
 
-        request["url"] = _get_url(current_request, lambda_context)
+        request_info["method"] = current_request.context["httpMethod"]
 
-        if "query_params" in current_request.to_dict():
-            request["query_string"] = current_request.query_params
+        request_info["query_string"] = current_request.query_params
 
-        if "headers" in current_request.to_dict():
-            request["headers"] = _filter_headers(current_request.headers)
+        request_info["headers"] = _filter_headers(current_request.headers)
 
         if current_request._body is None:
-            # Unfortunately couldn't find a way to get structured body from AWS
-            # event. Meaning every body is unstructured to us.
-            request["data"] = AnnotatedValue(
+            request_info["data"] = AnnotatedValue(
                 "", {"rem": [["!raw", "x", 0, 0]]}
             )
 
@@ -136,47 +158,8 @@ def _make_request_event_processor(current_request, lambda_context):
             if ip is not None:
                 user_info.setdefault("ip_address", ip)
 
-        event["request"] = request
+        event["request"] = request_info
 
         return event
 
     return event_processor
-
-
-def _get_url(event, context):
-    # type: (Any, Any) -> str
-    path = event.context["path"]
-    headers = event.headers
-    host = headers.get("Host", None)
-    proto = headers.get("X-Forwarded-Proto", None)
-    if proto and host and path:
-        return "{}://{}{}".format(proto, host, path)
-    return "awslambda:///{}".format(context.function_name)
-
-
-def _get_cloudwatch_logs_url(context, start_time):
-    # type: (Any, datetime) -> str
-    """
-    Generates a CloudWatchLogs console URL based on the context object
-    Arguments:
-        context {Any} -- context from lambda handler
-    Returns:
-        str -- AWS Console URL to logs.
-    """
-    formatstring = "%Y-%m-%dT%H:%M:%S"
-
-    url = (
-        "https://console.aws.amazon.com/cloudwatch/home?region={region}"
-        "#logEventViewer:group={log_group};stream={log_stream}"
-        ";start={start_time};end={end_time}"
-    ).format(
-        region=environ.get("AWS_REGION"),
-        log_group=context.log_group_name,
-        log_stream=context.log_stream_name,
-        start_time=(start_time - timedelta(seconds=1)).strftime(formatstring),
-        end_time=(datetime.now() + timedelta(seconds=2)).strftime(
-            formatstring
-        ),
-    )
-
-    return url
