@@ -1,6 +1,6 @@
 import pytest
 import sentry_sdk
-from chalice import Chalice
+from chalice import BadRequestError, Chalice
 
 from sentry_chalice import ChaliceIntegration
 
@@ -20,6 +20,10 @@ def app():
     def has_request():
         raise Exception('boom goes the dynamite!')
 
+    @app.route('/badrequest')
+    def badrequest():
+        raise BadRequestError('bad-request')
+
     return app
 
 
